# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'addresses': 'list[str]',
        'sanction_list': 'str',
        'aliases': 'list[str]',
        'programs': 'list[str]'
    }

    attribute_map = {
        'addresses': 'addresses',
        'sanction_list': 'sanctionList',
        'aliases': 'aliases',
        'programs': 'programs'
    }

    def __init__(self, addresses=None, sanction_list=None, aliases=None, programs=None):
        """
        RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches - a model defined in Swagger
        """

        self._addresses = None
        self._sanction_list = None
        self._aliases = None
        self._programs = None

        if addresses is not None:
          self.addresses = addresses
        if sanction_list is not None:
          self.sanction_list = sanction_list
        if aliases is not None:
          self.aliases = aliases
        if programs is not None:
          self.programs = programs

    @property
    def addresses(self):
        """
        Gets the addresses of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches.
        Address found on the list specified in export_matchN_list for the entity (name and address) in the request. 

        :return: The addresses of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches.
        :rtype: list[str]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """
        Sets the addresses of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches.
        Address found on the list specified in export_matchN_list for the entity (name and address) in the request. 

        :param addresses: The addresses of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches.
        :type: list[str]
        """

        self._addresses = addresses

    @property
    def sanction_list(self):
        """
        Gets the sanction_list of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches.
        List on which the first Denied Parties List check match appears. For a list of codes, see \"Denied Parties List Check Codes,\" page 56. 

        :return: The sanction_list of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches.
        :rtype: str
        """
        return self._sanction_list

    @sanction_list.setter
    def sanction_list(self, sanction_list):
        """
        Sets the sanction_list of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches.
        List on which the first Denied Parties List check match appears. For a list of codes, see \"Denied Parties List Check Codes,\" page 56. 

        :param sanction_list: The sanction_list of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches.
        :type: str
        """
        if sanction_list is not None and len(sanction_list) > 255:
            raise ValueError("Invalid value for `sanction_list`, length must be less than or equal to `255`")

        self._sanction_list = sanction_list

    @property
    def aliases(self):
        """
        Gets the aliases of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches.
        Name found on the list specified in export_matchN_list for the entity (name and address) in the request. 

        :return: The aliases of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches.
        :rtype: list[str]
        """
        return self._aliases

    @aliases.setter
    def aliases(self, aliases):
        """
        Sets the aliases of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches.
        Name found on the list specified in export_matchN_list for the entity (name and address) in the request. 

        :param aliases: The aliases of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches.
        :type: list[str]
        """

        self._aliases = aliases

    @property
    def programs(self):
        """
        Gets the programs of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches.
        Sub-lists matched by the order data. List members are separated by carets (^).

        :return: The programs of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches.
        :rtype: list[str]
        """
        return self._programs

    @programs.setter
    def programs(self, programs):
        """
        Sets the programs of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches.
        Sub-lists matched by the order data. List members are separated by carets (^).

        :param programs: The programs of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches.
        :type: list[str]
        """

        self._programs = programs

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchListMatches):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ReportingV3NetFundingsGet200ResponseNetFundingSummaries(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'payment_sub_type': 'str',
        'conveyed_count': 'int',
        'conveyed_amount': 'str',
        'settled_count': 'int',
        'funded_count': 'int',
        'funded_amount': 'str',
        'currency_code': 'str'
    }

    attribute_map = {
        'type': 'type',
        'payment_sub_type': 'paymentSubType',
        'conveyed_count': 'conveyedCount',
        'conveyed_amount': 'conveyedAmount',
        'settled_count': 'settledCount',
        'funded_count': 'fundedCount',
        'funded_amount': 'fundedAmount',
        'currency_code': 'currencyCode'
    }

    def __init__(self, type=None, payment_sub_type=None, conveyed_count=None, conveyed_amount=None, settled_count=None, funded_count=None, funded_amount=None, currency_code=None):
        """
        ReportingV3NetFundingsGet200ResponseNetFundingSummaries - a model defined in Swagger
        """

        self._type = None
        self._payment_sub_type = None
        self._conveyed_count = None
        self._conveyed_amount = None
        self._settled_count = None
        self._funded_count = None
        self._funded_amount = None
        self._currency_code = None

        if type is not None:
          self.type = type
        if payment_sub_type is not None:
          self.payment_sub_type = payment_sub_type
        if conveyed_count is not None:
          self.conveyed_count = conveyed_count
        if conveyed_amount is not None:
          self.conveyed_amount = conveyed_amount
        if settled_count is not None:
          self.settled_count = settled_count
        if funded_count is not None:
          self.funded_count = funded_count
        if funded_amount is not None:
          self.funded_amount = funded_amount
        if currency_code is not None:
          self.currency_code = currency_code

    @property
    def type(self):
        """
        Gets the type of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        Valid values: - PURCHASES - REFUNDS - FEES - CHARGEBACKS 

        :return: The type of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        Valid values: - PURCHASES - REFUNDS - FEES - CHARGEBACKS 

        :param type: The type of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        :type: str
        """

        self._type = type

    @property
    def payment_sub_type(self):
        """
        Gets the payment_sub_type of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.

        :return: The payment_sub_type of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        :rtype: str
        """
        return self._payment_sub_type

    @payment_sub_type.setter
    def payment_sub_type(self, payment_sub_type):
        """
        Sets the payment_sub_type of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.

        :param payment_sub_type: The payment_sub_type of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        :type: str
        """

        self._payment_sub_type = payment_sub_type

    @property
    def conveyed_count(self):
        """
        Gets the conveyed_count of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.

        :return: The conveyed_count of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        :rtype: int
        """
        return self._conveyed_count

    @conveyed_count.setter
    def conveyed_count(self, conveyed_count):
        """
        Sets the conveyed_count of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.

        :param conveyed_count: The conveyed_count of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        :type: int
        """

        self._conveyed_count = conveyed_count

    @property
    def conveyed_amount(self):
        """
        Gets the conveyed_amount of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.

        :return: The conveyed_amount of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        :rtype: str
        """
        return self._conveyed_amount

    @conveyed_amount.setter
    def conveyed_amount(self, conveyed_amount):
        """
        Sets the conveyed_amount of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.

        :param conveyed_amount: The conveyed_amount of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        :type: str
        """

        self._conveyed_amount = conveyed_amount

    @property
    def settled_count(self):
        """
        Gets the settled_count of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.

        :return: The settled_count of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        :rtype: int
        """
        return self._settled_count

    @settled_count.setter
    def settled_count(self, settled_count):
        """
        Sets the settled_count of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.

        :param settled_count: The settled_count of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        :type: int
        """

        self._settled_count = settled_count

    @property
    def funded_count(self):
        """
        Gets the funded_count of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.

        :return: The funded_count of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        :rtype: int
        """
        return self._funded_count

    @funded_count.setter
    def funded_count(self, funded_count):
        """
        Sets the funded_count of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.

        :param funded_count: The funded_count of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        :type: int
        """

        self._funded_count = funded_count

    @property
    def funded_amount(self):
        """
        Gets the funded_amount of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.

        :return: The funded_amount of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        :rtype: str
        """
        return self._funded_amount

    @funded_amount.setter
    def funded_amount(self, funded_amount):
        """
        Sets the funded_amount of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.

        :param funded_amount: The funded_amount of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        :type: str
        """

        self._funded_amount = funded_amount

    @property
    def currency_code(self):
        """
        Gets the currency_code of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        Valid ISO 4217 ALPHA-3 currency code

        :return: The currency_code of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """
        Sets the currency_code of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        Valid ISO 4217 ALPHA-3 currency code

        :param currency_code: The currency_code of this ReportingV3NetFundingsGet200ResponseNetFundingSummaries.
        :type: str
        """

        self._currency_code = currency_code

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ReportingV3NetFundingsGet200ResponseNetFundingSummaries):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsidrefundsOrderInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount_details': 'Ptsv2paymentsidcapturesOrderInformationAmountDetails',
        'bill_to': 'Ptsv2paymentsidcapturesOrderInformationBillTo',
        'ship_to': 'Ptsv2paymentsidcapturesOrderInformationShipTo',
        'line_items': 'list[Ptsv2paymentsidrefundsOrderInformationLineItems]',
        'invoice_details': 'Ptsv2paymentsidcapturesOrderInformationInvoiceDetails',
        'shipping_details': 'Ptsv2paymentsidcapturesOrderInformationShippingDetails'
    }

    attribute_map = {
        'amount_details': 'amountDetails',
        'bill_to': 'billTo',
        'ship_to': 'shipTo',
        'line_items': 'lineItems',
        'invoice_details': 'invoiceDetails',
        'shipping_details': 'shippingDetails'
    }

    def __init__(self, amount_details=None, bill_to=None, ship_to=None, line_items=None, invoice_details=None, shipping_details=None):
        """
        Ptsv2paymentsidrefundsOrderInformation - a model defined in Swagger
        """

        self._amount_details = None
        self._bill_to = None
        self._ship_to = None
        self._line_items = None
        self._invoice_details = None
        self._shipping_details = None

        if amount_details is not None:
          self.amount_details = amount_details
        if bill_to is not None:
          self.bill_to = bill_to
        if ship_to is not None:
          self.ship_to = ship_to
        if line_items is not None:
          self.line_items = line_items
        if invoice_details is not None:
          self.invoice_details = invoice_details
        if shipping_details is not None:
          self.shipping_details = shipping_details

    @property
    def amount_details(self):
        """
        Gets the amount_details of this Ptsv2paymentsidrefundsOrderInformation.

        :return: The amount_details of this Ptsv2paymentsidrefundsOrderInformation.
        :rtype: Ptsv2paymentsidcapturesOrderInformationAmountDetails
        """
        return self._amount_details

    @amount_details.setter
    def amount_details(self, amount_details):
        """
        Sets the amount_details of this Ptsv2paymentsidrefundsOrderInformation.

        :param amount_details: The amount_details of this Ptsv2paymentsidrefundsOrderInformation.
        :type: Ptsv2paymentsidcapturesOrderInformationAmountDetails
        """

        self._amount_details = amount_details

    @property
    def bill_to(self):
        """
        Gets the bill_to of this Ptsv2paymentsidrefundsOrderInformation.

        :return: The bill_to of this Ptsv2paymentsidrefundsOrderInformation.
        :rtype: Ptsv2paymentsidcapturesOrderInformationBillTo
        """
        return self._bill_to

    @bill_to.setter
    def bill_to(self, bill_to):
        """
        Sets the bill_to of this Ptsv2paymentsidrefundsOrderInformation.

        :param bill_to: The bill_to of this Ptsv2paymentsidrefundsOrderInformation.
        :type: Ptsv2paymentsidcapturesOrderInformationBillTo
        """

        self._bill_to = bill_to

    @property
    def ship_to(self):
        """
        Gets the ship_to of this Ptsv2paymentsidrefundsOrderInformation.

        :return: The ship_to of this Ptsv2paymentsidrefundsOrderInformation.
        :rtype: Ptsv2paymentsidcapturesOrderInformationShipTo
        """
        return self._ship_to

    @ship_to.setter
    def ship_to(self, ship_to):
        """
        Sets the ship_to of this Ptsv2paymentsidrefundsOrderInformation.

        :param ship_to: The ship_to of this Ptsv2paymentsidrefundsOrderInformation.
        :type: Ptsv2paymentsidcapturesOrderInformationShipTo
        """

        self._ship_to = ship_to

    @property
    def line_items(self):
        """
        Gets the line_items of this Ptsv2paymentsidrefundsOrderInformation.

        :return: The line_items of this Ptsv2paymentsidrefundsOrderInformation.
        :rtype: list[Ptsv2paymentsidrefundsOrderInformationLineItems]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """
        Sets the line_items of this Ptsv2paymentsidrefundsOrderInformation.

        :param line_items: The line_items of this Ptsv2paymentsidrefundsOrderInformation.
        :type: list[Ptsv2paymentsidrefundsOrderInformationLineItems]
        """

        self._line_items = line_items

    @property
    def invoice_details(self):
        """
        Gets the invoice_details of this Ptsv2paymentsidrefundsOrderInformation.

        :return: The invoice_details of this Ptsv2paymentsidrefundsOrderInformation.
        :rtype: Ptsv2paymentsidcapturesOrderInformationInvoiceDetails
        """
        return self._invoice_details

    @invoice_details.setter
    def invoice_details(self, invoice_details):
        """
        Sets the invoice_details of this Ptsv2paymentsidrefundsOrderInformation.

        :param invoice_details: The invoice_details of this Ptsv2paymentsidrefundsOrderInformation.
        :type: Ptsv2paymentsidcapturesOrderInformationInvoiceDetails
        """

        self._invoice_details = invoice_details

    @property
    def shipping_details(self):
        """
        Gets the shipping_details of this Ptsv2paymentsidrefundsOrderInformation.

        :return: The shipping_details of this Ptsv2paymentsidrefundsOrderInformation.
        :rtype: Ptsv2paymentsidcapturesOrderInformationShippingDetails
        """
        return self._shipping_details

    @shipping_details.setter
    def shipping_details(self, shipping_details):
        """
        Sets the shipping_details of this Ptsv2paymentsidrefundsOrderInformation.

        :param shipping_details: The shipping_details of this Ptsv2paymentsidrefundsOrderInformation.
        :type: Ptsv2paymentsidcapturesOrderInformationShippingDetails
        """

        self._shipping_details = shipping_details

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsidrefundsOrderInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address_type': 'str',
        'bar_code': 'RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationBarCode',
        'applicable_region': 'str',
        'error_code': 'str',
        'status_code': 'str',
        'care_of': 'str',
        'match_score': 'int',
        'standard_address': 'RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationStandardAddress'
    }

    attribute_map = {
        'address_type': 'addressType',
        'bar_code': 'barCode',
        'applicable_region': 'applicableRegion',
        'error_code': 'errorCode',
        'status_code': 'statusCode',
        'care_of': 'careOf',
        'match_score': 'matchScore',
        'standard_address': 'standardAddress'
    }

    def __init__(self, address_type=None, bar_code=None, applicable_region=None, error_code=None, status_code=None, care_of=None, match_score=None, standard_address=None):
        """
        RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation - a model defined in Swagger
        """

        self._address_type = None
        self._bar_code = None
        self._applicable_region = None
        self._error_code = None
        self._status_code = None
        self._care_of = None
        self._match_score = None
        self._standard_address = None

        if address_type is not None:
          self.address_type = address_type
        if bar_code is not None:
          self.bar_code = bar_code
        if applicable_region is not None:
          self.applicable_region = applicable_region
        if error_code is not None:
          self.error_code = error_code
        if status_code is not None:
          self.status_code = status_code
        if care_of is not None:
          self.care_of = care_of
        if match_score is not None:
          self.match_score = match_score
        if standard_address is not None:
          self.standard_address = standard_address

    @property
    def address_type(self):
        """
        Gets the address_type of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        Contains the record type of the postal code with which the address was matched.  #### U.S. Addresses Depending on the quantity and quality of the address information provided, this field contains one or two characters:  - One character: sufficient correct information was provided to result in accurate matching. - Two characters: standardization would provide a better address if more or better input address information were available. The second character is D (default).  Blank fields are unassigned. When an address cannot be standardized, how the input data was parsed determines the address type. In this case, standardization may indicate a street, rural route, highway contract, general delivery, or PO box. For possible values, see the description for the `dav_address_type` reply field in [CyberSource Verification Services Using the SCMP API](https://apps.cybersource.com/library/documentation/dev_guides/Verification_Svcs_SCMP_API/html/)  #### All Other Countries This field contains one of the following values: - P: Post. - S: Street. - x: Unknown. 

        :return: The address_type of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        :rtype: str
        """
        return self._address_type

    @address_type.setter
    def address_type(self, address_type):
        """
        Sets the address_type of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        Contains the record type of the postal code with which the address was matched.  #### U.S. Addresses Depending on the quantity and quality of the address information provided, this field contains one or two characters:  - One character: sufficient correct information was provided to result in accurate matching. - Two characters: standardization would provide a better address if more or better input address information were available. The second character is D (default).  Blank fields are unassigned. When an address cannot be standardized, how the input data was parsed determines the address type. In this case, standardization may indicate a street, rural route, highway contract, general delivery, or PO box. For possible values, see the description for the `dav_address_type` reply field in [CyberSource Verification Services Using the SCMP API](https://apps.cybersource.com/library/documentation/dev_guides/Verification_Svcs_SCMP_API/html/)  #### All Other Countries This field contains one of the following values: - P: Post. - S: Street. - x: Unknown. 

        :param address_type: The address_type of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        :type: str
        """
        if address_type is not None and len(address_type) > 255:
            raise ValueError("Invalid value for `address_type`, length must be less than or equal to `255`")

        self._address_type = address_type

    @property
    def bar_code(self):
        """
        Gets the bar_code of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.

        :return: The bar_code of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        :rtype: RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationBarCode
        """
        return self._bar_code

    @bar_code.setter
    def bar_code(self, bar_code):
        """
        Sets the bar_code of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.

        :param bar_code: The bar_code of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        :type: RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationBarCode
        """

        self._bar_code = bar_code

    @property
    def applicable_region(self):
        """
        Gets the applicable_region of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        Value can be - Canada - US - International The values of errorCode and statusCode mean different things depending on the applicable region. Refer to the guide for more info. 

        :return: The applicable_region of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        :rtype: str
        """
        return self._applicable_region

    @applicable_region.setter
    def applicable_region(self, applicable_region):
        """
        Sets the applicable_region of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        Value can be - Canada - US - International The values of errorCode and statusCode mean different things depending on the applicable region. Refer to the guide for more info. 

        :param applicable_region: The applicable_region of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        :type: str
        """
        if applicable_region is not None and len(applicable_region) > 255:
            raise ValueError("Invalid value for `applicable_region`, length must be less than or equal to `255`")

        self._applicable_region = applicable_region

    @property
    def error_code(self):
        """
        Gets the error_code of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        Four-character error code returned for Canadian, US and international addresses. For possible values, see Verification Services guide. The meaning of the errorCode depends on value of applicableRegion. 

        :return: The error_code of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """
        Sets the error_code of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        Four-character error code returned for Canadian, US and international addresses. For possible values, see Verification Services guide. The meaning of the errorCode depends on value of applicableRegion. 

        :param error_code: The error_code of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        :type: str
        """
        if error_code is not None and len(error_code) > 255:
            raise ValueError("Invalid value for `error_code`, length must be less than or equal to `255`")

        self._error_code = error_code

    @property
    def status_code(self):
        """
        Gets the status_code of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        Four-to-ten character status code returned for Canadian, US and international addresses. For possible values, see Verification Services guide. The meaning of the errorCode depends on value of applicableRegion. 

        :return: The status_code of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        :rtype: str
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """
        Sets the status_code of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        Four-to-ten character status code returned for Canadian, US and international addresses. For possible values, see Verification Services guide. The meaning of the errorCode depends on value of applicableRegion. 

        :param status_code: The status_code of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        :type: str
        """
        if status_code is not None and len(status_code) > 255:
            raise ValueError("Invalid value for `status_code`, length must be less than or equal to `255`")

        self._status_code = status_code

    @property
    def care_of(self):
        """
        Gets the care_of of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        Care of data dropped from the standard address.

        :return: The care_of of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        :rtype: str
        """
        return self._care_of

    @care_of.setter
    def care_of(self, care_of):
        """
        Sets the care_of of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        Care of data dropped from the standard address.

        :param care_of: The care_of of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        :type: str
        """
        if care_of is not None and len(care_of) > 255:
            raise ValueError("Invalid value for `care_of`, length must be less than or equal to `255`")

        self._care_of = care_of

    @property
    def match_score(self):
        """
        Gets the match_score of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        Indicates the probable correctness of the address match. Returned for U.S. and Canadian addresses. Returns a value from 0-9, where 0 is most likely to be correct and 9 is least likely to be correct, or -1 if there is no address match. 

        :return: The match_score of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        :rtype: int
        """
        return self._match_score

    @match_score.setter
    def match_score(self, match_score):
        """
        Sets the match_score of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        Indicates the probable correctness of the address match. Returned for U.S. and Canadian addresses. Returns a value from 0-9, where 0 is most likely to be correct and 9 is least likely to be correct, or -1 if there is no address match. 

        :param match_score: The match_score of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        :type: int
        """

        self._match_score = match_score

    @property
    def standard_address(self):
        """
        Gets the standard_address of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.

        :return: The standard_address of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        :rtype: RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationStandardAddress
        """
        return self._standard_address

    @standard_address.setter
    def standard_address(self, standard_address):
        """
        Sets the standard_address of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.

        :param standard_address: The standard_address of this RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation.
        :type: RiskV1AddressVerificationsPost201ResponseAddressVerificationInformationStandardAddress
        """

        self._standard_address = standard_address

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'company_tax_id': 'str',
        'currency': 'str',
        'date_of_birth': 'date',
        'personal_identification': 'list[Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformationPersonalIdentification]'
    }

    attribute_map = {
        'company_tax_id': 'companyTaxID',
        'currency': 'currency',
        'date_of_birth': 'dateOfBirth',
        'personal_identification': 'personalIdentification'
    }

    def __init__(self, company_tax_id=None, currency=None, date_of_birth=None, personal_identification=None):
        """
        Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation - a model defined in Swagger
        """

        self._company_tax_id = None
        self._currency = None
        self._date_of_birth = None
        self._personal_identification = None

        if company_tax_id is not None:
          self.company_tax_id = company_tax_id
        if currency is not None:
          self.currency = currency
        if date_of_birth is not None:
          self.date_of_birth = date_of_birth
        if personal_identification is not None:
          self.personal_identification = personal_identification

    @property
    def company_tax_id(self):
        """
        Gets the company_tax_id of this Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation.
        Company’s tax identifier. This is only used for eCheck service. 

        :return: The company_tax_id of this Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation.
        :rtype: str
        """
        return self._company_tax_id

    @company_tax_id.setter
    def company_tax_id(self, company_tax_id):
        """
        Sets the company_tax_id of this Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation.
        Company’s tax identifier. This is only used for eCheck service. 

        :param company_tax_id: The company_tax_id of this Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation.
        :type: str
        """
        if company_tax_id is not None and len(company_tax_id) > 9:
            raise ValueError("Invalid value for `company_tax_id`, length must be less than or equal to `9`")

        self._company_tax_id = company_tax_id

    @property
    def currency(self):
        """
        Gets the currency of this Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation.
        Currency used for the order. Use the three-character I[ISO Standard Currency Codes.](http://apps.cybersource.com/library/documentation/sbc/quickref/currencies.pdf)  For details about currency as used in partial authorizations, see \"Features for Debit Cards and Prepaid Cards\" in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  For an authorization reversal (`reversalInformation`) or a capture (`processingOptions.capture` is set to `true`), you must use the same currency that you used in your payment authorization request.  #### DCC for First Data Your local currency. For details, see the `currency` field description in [Dynamic Currency Conversion For First Data Using the SCMP API](http://apps.cybersource.com/library/documentation/dev_guides/DCC_FirstData_SCMP/DCC_FirstData_SCMP_API.pdf). 

        :return: The currency of this Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation.
        Currency used for the order. Use the three-character I[ISO Standard Currency Codes.](http://apps.cybersource.com/library/documentation/sbc/quickref/currencies.pdf)  For details about currency as used in partial authorizations, see \"Features for Debit Cards and Prepaid Cards\" in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  For an authorization reversal (`reversalInformation`) or a capture (`processingOptions.capture` is set to `true`), you must use the same currency that you used in your payment authorization request.  #### DCC for First Data Your local currency. For details, see the `currency` field description in [Dynamic Currency Conversion For First Data Using the SCMP API](http://apps.cybersource.com/library/documentation/dev_guides/DCC_FirstData_SCMP/DCC_FirstData_SCMP_API.pdf). 

        :param currency: The currency of this Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation.
        :type: str
        """
        if currency is not None and len(currency) > 3:
            raise ValueError("Invalid value for `currency`, length must be less than or equal to `3`")

        self._currency = currency

    @property
    def date_of_birth(self):
        """
        Gets the date_of_birth of this Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation.
        Date of birth of the customer. Format: YYYY-MM-DD 

        :return: The date_of_birth of this Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation.
        :rtype: date
        """
        return self._date_of_birth

    @date_of_birth.setter
    def date_of_birth(self, date_of_birth):
        """
        Sets the date_of_birth of this Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation.
        Date of birth of the customer. Format: YYYY-MM-DD 

        :param date_of_birth: The date_of_birth of this Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation.
        :type: date
        """

        self._date_of_birth = date_of_birth

    @property
    def personal_identification(self):
        """
        Gets the personal_identification of this Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation.

        :return: The personal_identification of this Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation.
        :rtype: list[Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformationPersonalIdentification]
        """
        return self._personal_identification

    @personal_identification.setter
    def personal_identification(self, personal_identification):
        """
        Sets the personal_identification of this Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation.

        :param personal_identification: The personal_identification of this Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation.
        :type: list[Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformationPersonalIdentification]
        """

        self._personal_identification = personal_identification

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Tmsv2customersEmbeddedDefaultPaymentInstrumentBuyerInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class JsonWebKey(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'kty': 'str',
        'use': 'str',
        'kid': 'str',
        'n': 'str',
        'e': 'str'
    }

    attribute_map = {
        'kty': 'kty',
        'use': 'use',
        'kid': 'kid',
        'n': 'n',
        'e': 'e'
    }

    def __init__(self, kty=None, use=None, kid=None, n=None, e=None):
        """
        JsonWebKey - a model defined in Swagger
        """

        self._kty = None
        self._use = None
        self._kid = None
        self._n = None
        self._e = None

        if kty is not None:
          self.kty = kty
        if use is not None:
          self.use = use
        if kid is not None:
          self.kid = kid
        if n is not None:
          self.n = n
        if e is not None:
          self.e = e

    @property
    def kty(self):
        """
        Gets the kty of this JsonWebKey.
        Algorithm used to encrypt the public key.

        :return: The kty of this JsonWebKey.
        :rtype: str
        """
        return self._kty

    @kty.setter
    def kty(self, kty):
        """
        Sets the kty of this JsonWebKey.
        Algorithm used to encrypt the public key.

        :param kty: The kty of this JsonWebKey.
        :type: str
        """

        self._kty = kty

    @property
    def use(self):
        """
        Gets the use of this JsonWebKey.
        Defines whether to use the key for encryption (enc) or verifying a signature (sig). Always returned as enc.

        :return: The use of this JsonWebKey.
        :rtype: str
        """
        return self._use

    @use.setter
    def use(self, use):
        """
        Sets the use of this JsonWebKey.
        Defines whether to use the key for encryption (enc) or verifying a signature (sig). Always returned as enc.

        :param use: The use of this JsonWebKey.
        :type: str
        """

        self._use = use

    @property
    def kid(self):
        """
        Gets the kid of this JsonWebKey.
        The key ID in JWK format.

        :return: The kid of this JsonWebKey.
        :rtype: str
        """
        return self._kid

    @kid.setter
    def kid(self, kid):
        """
        Sets the kid of this JsonWebKey.
        The key ID in JWK format.

        :param kid: The kid of this JsonWebKey.
        :type: str
        """

        self._kid = kid

    @property
    def n(self):
        """
        Gets the n of this JsonWebKey.
        JWK RSA Modulus

        :return: The n of this JsonWebKey.
        :rtype: str
        """
        return self._n

    @n.setter
    def n(self, n):
        """
        Sets the n of this JsonWebKey.
        JWK RSA Modulus

        :param n: The n of this JsonWebKey.
        :type: str
        """

        self._n = n

    @property
    def e(self):
        """
        Gets the e of this JsonWebKey.
        JWK RSA Exponent

        :return: The e of this JsonWebKey.
        :rtype: str
        """
        return self._e

    @e.setter
    def e(self, e):
        """
        Sets the e of this JsonWebKey.
        JWK RSA Exponent

        :param e: The e of this JsonWebKey.
        :type: str
        """

        self._e = e

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, JsonWebKey):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsTokenInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'jti': 'str',
        'transient_token_jwt': 'str',
        'payment_instrument': 'Ptsv2paymentsTokenInformationPaymentInstrument',
        'shipping_address': 'Ptsv2paymentsTokenInformationShippingAddress'
    }

    attribute_map = {
        'jti': 'jti',
        'transient_token_jwt': 'transientTokenJwt',
        'payment_instrument': 'paymentInstrument',
        'shipping_address': 'shippingAddress'
    }

    def __init__(self, jti=None, transient_token_jwt=None, payment_instrument=None, shipping_address=None):
        """
        Ptsv2paymentsTokenInformation - a model defined in Swagger
        """

        self._jti = None
        self._transient_token_jwt = None
        self._payment_instrument = None
        self._shipping_address = None

        if jti is not None:
          self.jti = jti
        if transient_token_jwt is not None:
          self.transient_token_jwt = transient_token_jwt
        if payment_instrument is not None:
          self.payment_instrument = payment_instrument
        if shipping_address is not None:
          self.shipping_address = shipping_address

    @property
    def jti(self):
        """
        Gets the jti of this Ptsv2paymentsTokenInformation.
        TMS Transient Token, 64 hexadecimal id value representing captured payment credentials (including Sensitive Authentication Data, e.g. CVV). 

        :return: The jti of this Ptsv2paymentsTokenInformation.
        :rtype: str
        """
        return self._jti

    @jti.setter
    def jti(self, jti):
        """
        Sets the jti of this Ptsv2paymentsTokenInformation.
        TMS Transient Token, 64 hexadecimal id value representing captured payment credentials (including Sensitive Authentication Data, e.g. CVV). 

        :param jti: The jti of this Ptsv2paymentsTokenInformation.
        :type: str
        """
        if jti is not None and len(jti) > 64:
            raise ValueError("Invalid value for `jti`, length must be less than or equal to `64`")

        self._jti = jti

    @property
    def transient_token_jwt(self):
        """
        Gets the transient_token_jwt of this Ptsv2paymentsTokenInformation.
        Flex API Transient Token encoded as JWT (JSON Web Token), e.g. Flex microform or Unified Payment checkout result. 

        :return: The transient_token_jwt of this Ptsv2paymentsTokenInformation.
        :rtype: str
        """
        return self._transient_token_jwt

    @transient_token_jwt.setter
    def transient_token_jwt(self, transient_token_jwt):
        """
        Sets the transient_token_jwt of this Ptsv2paymentsTokenInformation.
        Flex API Transient Token encoded as JWT (JSON Web Token), e.g. Flex microform or Unified Payment checkout result. 

        :param transient_token_jwt: The transient_token_jwt of this Ptsv2paymentsTokenInformation.
        :type: str
        """

        self._transient_token_jwt = transient_token_jwt

    @property
    def payment_instrument(self):
        """
        Gets the payment_instrument of this Ptsv2paymentsTokenInformation.

        :return: The payment_instrument of this Ptsv2paymentsTokenInformation.
        :rtype: Ptsv2paymentsTokenInformationPaymentInstrument
        """
        return self._payment_instrument

    @payment_instrument.setter
    def payment_instrument(self, payment_instrument):
        """
        Sets the payment_instrument of this Ptsv2paymentsTokenInformation.

        :param payment_instrument: The payment_instrument of this Ptsv2paymentsTokenInformation.
        :type: Ptsv2paymentsTokenInformationPaymentInstrument
        """

        self._payment_instrument = payment_instrument

    @property
    def shipping_address(self):
        """
        Gets the shipping_address of this Ptsv2paymentsTokenInformation.

        :return: The shipping_address of this Ptsv2paymentsTokenInformation.
        :rtype: Ptsv2paymentsTokenInformationShippingAddress
        """
        return self._shipping_address

    @shipping_address.setter
    def shipping_address(self, shipping_address):
        """
        Sets the shipping_address of this Ptsv2paymentsTokenInformation.

        :param shipping_address: The shipping_address of this Ptsv2paymentsTokenInformation.
        :type: Ptsv2paymentsTokenInformationShippingAddress
        """

        self._shipping_address = shipping_address

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsTokenInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV1TransactionBatchesGet200ResponseTransactionBatches(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'upload_date': 'str',
        'completion_date': 'str',
        'transaction_count': 'int',
        'accepted_transaction_count': 'int',
        'rejected_transaction_count': 'str',
        'status': 'str'
    }

    attribute_map = {
        'id': 'id',
        'upload_date': 'uploadDate',
        'completion_date': 'completionDate',
        'transaction_count': 'transactionCount',
        'accepted_transaction_count': 'acceptedTransactionCount',
        'rejected_transaction_count': 'rejectedTransactionCount',
        'status': 'status'
    }

    def __init__(self, id=None, upload_date=None, completion_date=None, transaction_count=None, accepted_transaction_count=None, rejected_transaction_count=None, status=None):
        """
        PtsV1TransactionBatchesGet200ResponseTransactionBatches - a model defined in Swagger
        """

        self._id = None
        self._upload_date = None
        self._completion_date = None
        self._transaction_count = None
        self._accepted_transaction_count = None
        self._rejected_transaction_count = None
        self._status = None

        if id is not None:
          self.id = id
        if upload_date is not None:
          self.upload_date = upload_date
        if completion_date is not None:
          self.completion_date = completion_date
        if transaction_count is not None:
          self.transaction_count = transaction_count
        if accepted_transaction_count is not None:
          self.accepted_transaction_count = accepted_transaction_count
        if rejected_transaction_count is not None:
          self.rejected_transaction_count = rejected_transaction_count
        if status is not None:
          self.status = status

    @property
    def id(self):
        """
        Gets the id of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        Unique identifier assigned to the batch file.

        :return: The id of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        Unique identifier assigned to the batch file.

        :param id: The id of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        :type: str
        """
        if id is not None and len(id) > 8:
            raise ValueError("Invalid value for `id`, length must be less than or equal to `8`")
        if id is not None and len(id) < 1:
            raise ValueError("Invalid value for `id`, length must be greater than or equal to `1`")
        if id is not None and not re.search('^[a-zA-Z0-9_+-]*$', id):
            raise ValueError("Invalid value for `id`, must be a follow pattern or equal to `/^[a-zA-Z0-9_+-]*$/`")

        self._id = id

    @property
    def upload_date(self):
        """
        Gets the upload_date of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        Date when the batch template was update.

        :return: The upload_date of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        :rtype: str
        """
        return self._upload_date

    @upload_date.setter
    def upload_date(self, upload_date):
        """
        Sets the upload_date of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        Date when the batch template was update.

        :param upload_date: The upload_date of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        :type: str
        """

        self._upload_date = upload_date

    @property
    def completion_date(self):
        """
        Gets the completion_date of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        The date when the batch template processing completed.

        :return: The completion_date of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        :rtype: str
        """
        return self._completion_date

    @completion_date.setter
    def completion_date(self, completion_date):
        """
        Sets the completion_date of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        The date when the batch template processing completed.

        :param completion_date: The completion_date of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        :type: str
        """

        self._completion_date = completion_date

    @property
    def transaction_count(self):
        """
        Gets the transaction_count of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        Number of transactions in the transaction.

        :return: The transaction_count of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        :rtype: int
        """
        return self._transaction_count

    @transaction_count.setter
    def transaction_count(self, transaction_count):
        """
        Sets the transaction_count of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        Number of transactions in the transaction.

        :param transaction_count: The transaction_count of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        :type: int
        """

        self._transaction_count = transaction_count

    @property
    def accepted_transaction_count(self):
        """
        Gets the accepted_transaction_count of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        Number of transactions accepted.

        :return: The accepted_transaction_count of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        :rtype: int
        """
        return self._accepted_transaction_count

    @accepted_transaction_count.setter
    def accepted_transaction_count(self, accepted_transaction_count):
        """
        Sets the accepted_transaction_count of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        Number of transactions accepted.

        :param accepted_transaction_count: The accepted_transaction_count of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        :type: int
        """

        self._accepted_transaction_count = accepted_transaction_count

    @property
    def rejected_transaction_count(self):
        """
        Gets the rejected_transaction_count of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        Number of transactions rejected.

        :return: The rejected_transaction_count of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        :rtype: str
        """
        return self._rejected_transaction_count

    @rejected_transaction_count.setter
    def rejected_transaction_count(self, rejected_transaction_count):
        """
        Sets the rejected_transaction_count of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        Number of transactions rejected.

        :param rejected_transaction_count: The rejected_transaction_count of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        :type: str
        """

        self._rejected_transaction_count = rejected_transaction_count

    @property
    def status(self):
        """
        Gets the status of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        The status of you batch template processing.

        :return: The status of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        The status of you batch template processing.

        :param status: The status of this PtsV1TransactionBatchesGet200ResponseTransactionBatches.
        :type: str
        """

        self._status = status

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV1TransactionBatchesGet200ResponseTransactionBatches):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsPaymentInformationBankAccount(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'number': 'str',
        'encoder_id': 'str',
        'check_number': 'str',
        'check_image_reference_number': 'str'
    }

    attribute_map = {
        'type': 'type',
        'number': 'number',
        'encoder_id': 'encoderId',
        'check_number': 'checkNumber',
        'check_image_reference_number': 'checkImageReferenceNumber'
    }

    def __init__(self, type=None, number=None, encoder_id=None, check_number=None, check_image_reference_number=None):
        """
        Ptsv2paymentsPaymentInformationBankAccount - a model defined in Swagger
        """

        self._type = None
        self._number = None
        self._encoder_id = None
        self._check_number = None
        self._check_image_reference_number = None

        if type is not None:
          self.type = type
        if number is not None:
          self.number = number
        if encoder_id is not None:
          self.encoder_id = encoder_id
        if check_number is not None:
          self.check_number = check_number
        if check_image_reference_number is not None:
          self.check_image_reference_number = check_image_reference_number

    @property
    def type(self):
        """
        Gets the type of this Ptsv2paymentsPaymentInformationBankAccount.
        Account type.  Possible values:  - **C**: Checking.  - **G**: General ledger. This value is supported only on Wells Fargo ACH.  - **S**: Savings (U.S. dollars only).  - **X**: Corporate checking (U.S. dollars only). 

        :return: The type of this Ptsv2paymentsPaymentInformationBankAccount.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Ptsv2paymentsPaymentInformationBankAccount.
        Account type.  Possible values:  - **C**: Checking.  - **G**: General ledger. This value is supported only on Wells Fargo ACH.  - **S**: Savings (U.S. dollars only).  - **X**: Corporate checking (U.S. dollars only). 

        :param type: The type of this Ptsv2paymentsPaymentInformationBankAccount.
        :type: str
        """
        if type is not None and len(type) > 1:
            raise ValueError("Invalid value for `type`, length must be less than or equal to `1`")

        self._type = type

    @property
    def number(self):
        """
        Gets the number of this Ptsv2paymentsPaymentInformationBankAccount.
        Account number.  When processing encoded account numbers, use this field for the encoded account number. 

        :return: The number of this Ptsv2paymentsPaymentInformationBankAccount.
        :rtype: str
        """
        return self._number

    @number.setter
    def number(self, number):
        """
        Sets the number of this Ptsv2paymentsPaymentInformationBankAccount.
        Account number.  When processing encoded account numbers, use this field for the encoded account number. 

        :param number: The number of this Ptsv2paymentsPaymentInformationBankAccount.
        :type: str
        """
        if number is not None and len(number) > 17:
            raise ValueError("Invalid value for `number`, length must be less than or equal to `17`")

        self._number = number

    @property
    def encoder_id(self):
        """
        Gets the encoder_id of this Ptsv2paymentsPaymentInformationBankAccount.
        Identifier for the bank that provided the customer’s encoded account number.  To obtain the bank identifier, contact your processor.  For details, see `account_encoder_id` request-level field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The encoder_id of this Ptsv2paymentsPaymentInformationBankAccount.
        :rtype: str
        """
        return self._encoder_id

    @encoder_id.setter
    def encoder_id(self, encoder_id):
        """
        Sets the encoder_id of this Ptsv2paymentsPaymentInformationBankAccount.
        Identifier for the bank that provided the customer’s encoded account number.  To obtain the bank identifier, contact your processor.  For details, see `account_encoder_id` request-level field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param encoder_id: The encoder_id of this Ptsv2paymentsPaymentInformationBankAccount.
        :type: str
        """
        if encoder_id is not None and len(encoder_id) > 3:
            raise ValueError("Invalid value for `encoder_id`, length must be less than or equal to `3`")

        self._encoder_id = encoder_id

    @property
    def check_number(self):
        """
        Gets the check_number of this Ptsv2paymentsPaymentInformationBankAccount.
        Check number.  Chase Paymentech Solutions - Optional. CyberSource ACH Service - Not used. RBS WorldPay Atlanta - Optional on debits. Required on credits. TeleCheck - Strongly recommended on debit requests. Optional on credits. 

        :return: The check_number of this Ptsv2paymentsPaymentInformationBankAccount.
        :rtype: str
        """
        return self._check_number

    @check_number.setter
    def check_number(self, check_number):
        """
        Sets the check_number of this Ptsv2paymentsPaymentInformationBankAccount.
        Check number.  Chase Paymentech Solutions - Optional. CyberSource ACH Service - Not used. RBS WorldPay Atlanta - Optional on debits. Required on credits. TeleCheck - Strongly recommended on debit requests. Optional on credits. 

        :param check_number: The check_number of this Ptsv2paymentsPaymentInformationBankAccount.
        :type: str
        """
        if check_number is not None and len(check_number) > 8:
            raise ValueError("Invalid value for `check_number`, length must be less than or equal to `8`")

        self._check_number = check_number

    @property
    def check_image_reference_number(self):
        """
        Gets the check_image_reference_number of this Ptsv2paymentsPaymentInformationBankAccount.
        Image reference number associated with the check. You cannot include any special characters. 

        :return: The check_image_reference_number of this Ptsv2paymentsPaymentInformationBankAccount.
        :rtype: str
        """
        return self._check_image_reference_number

    @check_image_reference_number.setter
    def check_image_reference_number(self, check_image_reference_number):
        """
        Sets the check_image_reference_number of this Ptsv2paymentsPaymentInformationBankAccount.
        Image reference number associated with the check. You cannot include any special characters. 

        :param check_image_reference_number: The check_image_reference_number of this Ptsv2paymentsPaymentInformationBankAccount.
        :type: str
        """
        if check_image_reference_number is not None and len(check_image_reference_number) > 32:
            raise ValueError("Invalid value for `check_image_reference_number`, length must be less than or equal to `32`")

        self._check_image_reference_number = check_image_reference_number

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsPaymentInformationBankAccount):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsPost201ResponseProcessorInformationRouting(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'network': 'str',
        'network_name': 'str',
        'customer_signature_required': 'str'
    }

    attribute_map = {
        'network': 'network',
        'network_name': 'networkName',
        'customer_signature_required': 'customerSignatureRequired'
    }

    def __init__(self, network=None, network_name=None, customer_signature_required=None):
        """
        PtsV2PaymentsPost201ResponseProcessorInformationRouting - a model defined in Swagger
        """

        self._network = None
        self._network_name = None
        self._customer_signature_required = None

        if network is not None:
          self.network = network
        if network_name is not None:
          self.network_name = network_name
        if customer_signature_required is not None:
          self.customer_signature_required = customer_signature_required

    @property
    def network(self):
        """
        Gets the network of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        Indicates whether the transaction was routed on a credit network, a debit network, or the STAR signature debit network.  Possible values: - `C`: Credit network - `D`: Debit network (without signature) - `S`: STAR signature debit network  This field is supported only on FDC Nashville Global.  #### PIN debit Network that was used to route the transaction. This is the list of network codes:  | Network | Code | | --- | --- | | Accel | E | | AFFN | U | | Alaska Option | 3 | | CU24 | C | | Interlink | G | | Maestro | 8 | | NETS | P | | NYCE | F | | Pulse | H | | Shazam | 7 | | Star | M | | Visa | V |  Returned by PIN debit credit and PIN debit purchase. 

        :return: The network of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        :rtype: str
        """
        return self._network

    @network.setter
    def network(self, network):
        """
        Sets the network of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        Indicates whether the transaction was routed on a credit network, a debit network, or the STAR signature debit network.  Possible values: - `C`: Credit network - `D`: Debit network (without signature) - `S`: STAR signature debit network  This field is supported only on FDC Nashville Global.  #### PIN debit Network that was used to route the transaction. This is the list of network codes:  | Network | Code | | --- | --- | | Accel | E | | AFFN | U | | Alaska Option | 3 | | CU24 | C | | Interlink | G | | Maestro | 8 | | NETS | P | | NYCE | F | | Pulse | H | | Shazam | 7 | | Star | M | | Visa | V |  Returned by PIN debit credit and PIN debit purchase. 

        :param network: The network of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        :type: str
        """
        if network is not None and len(network) > 1:
            raise ValueError("Invalid value for `network`, length must be less than or equal to `1`")

        self._network = network

    @property
    def network_name(self):
        """
        Gets the network_name of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        Name of the network on which the transaction was routed.  This reply field is supported only on FDC Nashville Global. 

        :return: The network_name of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        :rtype: str
        """
        return self._network_name

    @network_name.setter
    def network_name(self, network_name):
        """
        Sets the network_name of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        Name of the network on which the transaction was routed.  This reply field is supported only on FDC Nashville Global. 

        :param network_name: The network_name of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        :type: str
        """
        if network_name is not None and len(network_name) > 10:
            raise ValueError("Invalid value for `network_name`, length must be less than or equal to `10`")

        self._network_name = network_name

    @property
    def customer_signature_required(self):
        """
        Gets the customer_signature_required of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        Indicates whether you need to obtain the cardholder's signature.  Possible values: - `Y`: You need to obtain the cardholder's signature. - `N`: You do not need to obtain the cardholder's signature.  This field is supported only on FDC Nashville Global. 

        :return: The customer_signature_required of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        :rtype: str
        """
        return self._customer_signature_required

    @customer_signature_required.setter
    def customer_signature_required(self, customer_signature_required):
        """
        Sets the customer_signature_required of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        Indicates whether you need to obtain the cardholder's signature.  Possible values: - `Y`: You need to obtain the cardholder's signature. - `N`: You do not need to obtain the cardholder's signature.  This field is supported only on FDC Nashville Global. 

        :param customer_signature_required: The customer_signature_required of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        :type: str
        """
        if customer_signature_required is not None and len(customer_signature_required) > 1:
            raise ValueError("Invalid value for `customer_signature_required`, length must be less than or equal to `1`")

        self._customer_signature_required = customer_signature_required

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsPost201ResponseProcessorInformationRouting):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'payment_method': 'str',
        'terminal_id': 'str',
        'business_name': 'str',
        'business_name_katakana': 'str'
    }

    attribute_map = {
        'payment_method': 'paymentMethod',
        'terminal_id': 'terminalId',
        'business_name': 'businessName',
        'business_name_katakana': 'businessNameKatakana'
    }

    def __init__(self, payment_method=None, terminal_id=None, business_name=None, business_name_katakana=None):
        """
        TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions - a model defined in Swagger
        """

        self._payment_method = None
        self._terminal_id = None
        self._business_name = None
        self._business_name_katakana = None

        if payment_method is not None:
          self.payment_method = payment_method
        if terminal_id is not None:
          self.terminal_id = terminal_id
        if business_name is not None:
          self.business_name = business_name
        if business_name_katakana is not None:
          self.business_name_katakana = business_name_katakana

    @property
    def payment_method(self):
        """
        Gets the payment_method of this TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions.
        This value is a 2-digit code indicating the payment method. Use Payment Method Code value that applies to the tranasction. - 10 (One-time payment) - 21, 22, 23, 24  (Bonus(one-time)payment) - 61 (Installment payment) - 31, 32, 33, 34  (Integrated (Bonus + Installment)payment) - 80 (Revolving payment) 

        :return: The payment_method of this TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions.
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """
        Sets the payment_method of this TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions.
        This value is a 2-digit code indicating the payment method. Use Payment Method Code value that applies to the tranasction. - 10 (One-time payment) - 21, 22, 23, 24  (Bonus(one-time)payment) - 61 (Installment payment) - 31, 32, 33, 34  (Integrated (Bonus + Installment)payment) - 80 (Revolving payment) 

        :param payment_method: The payment_method of this TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions.
        :type: str
        """
        if payment_method is not None and len(payment_method) > 2:
            raise ValueError("Invalid value for `payment_method`, length must be less than or equal to `2`")

        self._payment_method = payment_method

    @property
    def terminal_id(self):
        """
        Gets the terminal_id of this TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions.
        Unique Japan Credit Card Association (JCCA) terminal identifier.  The difference between this field and the `pointOfSaleInformation.terminalID` field is that you can define `pointOfSaleInformation.terminalID`, but `processingInformation.japanPaymentOptions.terminalId` is defined by the JCCA and is used only in Japan.  This field is supported only on CyberSource through VisaNet and JCN Gateway.  Optional field. 

        :return: The terminal_id of this TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions.
        :rtype: str
        """
        return self._terminal_id

    @terminal_id.setter
    def terminal_id(self, terminal_id):
        """
        Sets the terminal_id of this TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions.
        Unique Japan Credit Card Association (JCCA) terminal identifier.  The difference between this field and the `pointOfSaleInformation.terminalID` field is that you can define `pointOfSaleInformation.terminalID`, but `processingInformation.japanPaymentOptions.terminalId` is defined by the JCCA and is used only in Japan.  This field is supported only on CyberSource through VisaNet and JCN Gateway.  Optional field. 

        :param terminal_id: The terminal_id of this TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions.
        :type: str
        """
        if terminal_id is not None and len(terminal_id) > 13:
            raise ValueError("Invalid value for `terminal_id`, length must be less than or equal to `13`")

        self._terminal_id = terminal_id

    @property
    def business_name(self):
        """
        Gets the business_name of this TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions.
        Business name in Japanese characters. This field is supported only on JCN Gateway and for the Sumitomo Mitsui Card Co. acquirer on CyberSource through VisaNet. 

        :return: The business_name of this TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions.
        :rtype: str
        """
        return self._business_name

    @business_name.setter
    def business_name(self, business_name):
        """
        Sets the business_name of this TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions.
        Business name in Japanese characters. This field is supported only on JCN Gateway and for the Sumitomo Mitsui Card Co. acquirer on CyberSource through VisaNet. 

        :param business_name: The business_name of this TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions.
        :type: str
        """
        if business_name is not None and len(business_name) > 25:
            raise ValueError("Invalid value for `business_name`, length must be less than or equal to `25`")

        self._business_name = business_name

    @property
    def business_name_katakana(self):
        """
        Gets the business_name_katakana of this TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions.
        Business name in Katakana characters. This field is supported only on JCN Gateway and for the Sumitomo Mitsui Card Co. acquirer on CyberSource through VisaNet. 

        :return: The business_name_katakana of this TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions.
        :rtype: str
        """
        return self._business_name_katakana

    @business_name_katakana.setter
    def business_name_katakana(self, business_name_katakana):
        """
        Sets the business_name_katakana of this TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions.
        Business name in Katakana characters. This field is supported only on JCN Gateway and for the Sumitomo Mitsui Card Co. acquirer on CyberSource through VisaNet. 

        :param business_name_katakana: The business_name_katakana of this TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions.
        :type: str
        """
        if business_name_katakana is not None and len(business_name_katakana) > 25:
            raise ValueError("Invalid value for `business_name_katakana`, length must be less than or equal to `25`")

        self._business_name_katakana = business_name_katakana

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TssV2TransactionsGet200ResponseProcessingInformationJapanPaymentOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsOrderInformationPassenger(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'status': 'str',
        'phone': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'id': 'str',
        'email': 'str',
        'nationality': 'str'
    }

    attribute_map = {
        'type': 'type',
        'status': 'status',
        'phone': 'phone',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'id': 'id',
        'email': 'email',
        'nationality': 'nationality'
    }

    def __init__(self, type=None, status=None, phone=None, first_name=None, last_name=None, id=None, email=None, nationality=None):
        """
        Ptsv2paymentsOrderInformationPassenger - a model defined in Swagger
        """

        self._type = None
        self._status = None
        self._phone = None
        self._first_name = None
        self._last_name = None
        self._id = None
        self._email = None
        self._nationality = None

        if type is not None:
          self.type = type
        if status is not None:
          self.status = status
        if phone is not None:
          self.phone = phone
        if first_name is not None:
          self.first_name = first_name
        if last_name is not None:
          self.last_name = last_name
        if id is not None:
          self.id = id
        if email is not None:
          self.email = email
        if nationality is not None:
          self.nationality = nationality

    @property
    def type(self):
        """
        Gets the type of this Ptsv2paymentsOrderInformationPassenger.
        Passenger classification associated with the price of the ticket. You can use one of the following values: - `ADT`: Adult - `CNN`: Child - `INF`: Infant - `YTH`: Youth - `STU`: Student - `SCR`: Senior Citizen - `MIL`: Military 

        :return: The type of this Ptsv2paymentsOrderInformationPassenger.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Ptsv2paymentsOrderInformationPassenger.
        Passenger classification associated with the price of the ticket. You can use one of the following values: - `ADT`: Adult - `CNN`: Child - `INF`: Infant - `YTH`: Youth - `STU`: Student - `SCR`: Senior Citizen - `MIL`: Military 

        :param type: The type of this Ptsv2paymentsOrderInformationPassenger.
        :type: str
        """
        if type is not None and len(type) > 32:
            raise ValueError("Invalid value for `type`, length must be less than or equal to `32`")

        self._type = type

    @property
    def status(self):
        """
        Gets the status of this Ptsv2paymentsOrderInformationPassenger.
        Your company's passenger classification, such as with a frequent flyer program. In this case, you might use values such as `standard`, `gold`, or `platinum`. 

        :return: The status of this Ptsv2paymentsOrderInformationPassenger.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Ptsv2paymentsOrderInformationPassenger.
        Your company's passenger classification, such as with a frequent flyer program. In this case, you might use values such as `standard`, `gold`, or `platinum`. 

        :param status: The status of this Ptsv2paymentsOrderInformationPassenger.
        :type: str
        """
        if status is not None and len(status) > 32:
            raise ValueError("Invalid value for `status`, length must be less than or equal to `32`")

        self._status = status

    @property
    def phone(self):
        """
        Gets the phone of this Ptsv2paymentsOrderInformationPassenger.
        Passenger's phone number. If the order is from outside the U.S., CyberSource recommends that you include the [ISO Standard Country Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf). 

        :return: The phone of this Ptsv2paymentsOrderInformationPassenger.
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """
        Sets the phone of this Ptsv2paymentsOrderInformationPassenger.
        Passenger's phone number. If the order is from outside the U.S., CyberSource recommends that you include the [ISO Standard Country Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf). 

        :param phone: The phone of this Ptsv2paymentsOrderInformationPassenger.
        :type: str
        """
        if phone is not None and len(phone) > 15:
            raise ValueError("Invalid value for `phone`, length must be less than or equal to `15`")

        self._phone = phone

    @property
    def first_name(self):
        """
        Gets the first_name of this Ptsv2paymentsOrderInformationPassenger.
        Passenger's first name.

        :return: The first_name of this Ptsv2paymentsOrderInformationPassenger.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this Ptsv2paymentsOrderInformationPassenger.
        Passenger's first name.

        :param first_name: The first_name of this Ptsv2paymentsOrderInformationPassenger.
        :type: str
        """
        if first_name is not None and len(first_name) > 60:
            raise ValueError("Invalid value for `first_name`, length must be less than or equal to `60`")

        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this Ptsv2paymentsOrderInformationPassenger.
        Passenger's last name.

        :return: The last_name of this Ptsv2paymentsOrderInformationPassenger.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this Ptsv2paymentsOrderInformationPassenger.
        Passenger's last name.

        :param last_name: The last_name of this Ptsv2paymentsOrderInformationPassenger.
        :type: str
        """
        if last_name is not None and len(last_name) > 60:
            raise ValueError("Invalid value for `last_name`, length must be less than or equal to `60`")

        self._last_name = last_name

    @property
    def id(self):
        """
        Gets the id of this Ptsv2paymentsOrderInformationPassenger.
        ID of the passenger to whom the ticket was issued. For example, you can use this field for the frequent flyer number. 

        :return: The id of this Ptsv2paymentsOrderInformationPassenger.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Ptsv2paymentsOrderInformationPassenger.
        ID of the passenger to whom the ticket was issued. For example, you can use this field for the frequent flyer number. 

        :param id: The id of this Ptsv2paymentsOrderInformationPassenger.
        :type: str
        """
        if id is not None and len(id) > 40:
            raise ValueError("Invalid value for `id`, length must be less than or equal to `40`")

        self._id = id

    @property
    def email(self):
        """
        Gets the email of this Ptsv2paymentsOrderInformationPassenger.
        Passenger's email address, including the full domain name, such as jdoe@example.com.

        :return: The email of this Ptsv2paymentsOrderInformationPassenger.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this Ptsv2paymentsOrderInformationPassenger.
        Passenger's email address, including the full domain name, such as jdoe@example.com.

        :param email: The email of this Ptsv2paymentsOrderInformationPassenger.
        :type: str
        """
        if email is not None and len(email) > 255:
            raise ValueError("Invalid value for `email`, length must be less than or equal to `255`")

        self._email = email

    @property
    def nationality(self):
        """
        Gets the nationality of this Ptsv2paymentsOrderInformationPassenger.
        Passenger's nationality country. Use the two character [ISO Standard Country Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf).

        :return: The nationality of this Ptsv2paymentsOrderInformationPassenger.
        :rtype: str
        """
        return self._nationality

    @nationality.setter
    def nationality(self, nationality):
        """
        Sets the nationality of this Ptsv2paymentsOrderInformationPassenger.
        Passenger's nationality country. Use the two character [ISO Standard Country Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf).

        :param nationality: The nationality of this Ptsv2paymentsOrderInformationPassenger.
        :type: str
        """
        if nationality is not None and len(nationality) > 2:
            raise ValueError("Invalid value for `nationality`, length must be less than or equal to `2`")

        self._nationality = nationality

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsOrderInformationPassenger):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PayoutsPost201Response(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'PtsV2IncrementalAuthorizationPatch201ResponseLinks',
        'id': 'str',
        'submit_time_utc': 'str',
        'status': 'str',
        'reconciliation_id': 'str',
        'error_information': 'PtsV2PayoutsPost201ResponseErrorInformation',
        'client_reference_information': 'PtsV2PaymentsPost201ResponseClientReferenceInformation',
        'merchant_information': 'PtsV2PayoutsPost201ResponseMerchantInformation',
        'order_information': 'PtsV2PayoutsPost201ResponseOrderInformation',
        'processor_information': 'PtsV2PayoutsPost201ResponseProcessorInformation',
        'recipient_information': 'PtsV2PayoutsPost201ResponseRecipientInformation'
    }

    attribute_map = {
        'links': '_links',
        'id': 'id',
        'submit_time_utc': 'submitTimeUtc',
        'status': 'status',
        'reconciliation_id': 'reconciliationId',
        'error_information': 'errorInformation',
        'client_reference_information': 'clientReferenceInformation',
        'merchant_information': 'merchantInformation',
        'order_information': 'orderInformation',
        'processor_information': 'processorInformation',
        'recipient_information': 'recipientInformation'
    }

    def __init__(self, links=None, id=None, submit_time_utc=None, status=None, reconciliation_id=None, error_information=None, client_reference_information=None, merchant_information=None, order_information=None, processor_information=None, recipient_information=None):
        """
        PtsV2PayoutsPost201Response - a model defined in Swagger
        """

        self._links = None
        self._id = None
        self._submit_time_utc = None
        self._status = None
        self._reconciliation_id = None
        self._error_information = None
        self._client_reference_information = None
        self._merchant_information = None
        self._order_information = None
        self._processor_information = None
        self._recipient_information = None

        if links is not None:
          self.links = links
        if id is not None:
          self.id = id
        if submit_time_utc is not None:
          self.submit_time_utc = submit_time_utc
        if status is not None:
          self.status = status
        if reconciliation_id is not None:
          self.reconciliation_id = reconciliation_id
        if error_information is not None:
          self.error_information = error_information
        if client_reference_information is not None:
          self.client_reference_information = client_reference_information
        if merchant_information is not None:
          self.merchant_information = merchant_information
        if order_information is not None:
          self.order_information = order_information
        if processor_information is not None:
          self.processor_information = processor_information
        if recipient_information is not None:
          self.recipient_information = recipient_information

    @property
    def links(self):
        """
        Gets the links of this PtsV2PayoutsPost201Response.

        :return: The links of this PtsV2PayoutsPost201Response.
        :rtype: PtsV2IncrementalAuthorizationPatch201ResponseLinks
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this PtsV2PayoutsPost201Response.

        :param links: The links of this PtsV2PayoutsPost201Response.
        :type: PtsV2IncrementalAuthorizationPatch201ResponseLinks
        """

        self._links = links

    @property
    def id(self):
        """
        Gets the id of this PtsV2PayoutsPost201Response.
        An unique identification number to identify the submitted request. It is also appended to the endpoint of the resource.  On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.  #### PIN debit Returned for all PIN debit services. 

        :return: The id of this PtsV2PayoutsPost201Response.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this PtsV2PayoutsPost201Response.
        An unique identification number to identify the submitted request. It is also appended to the endpoint of the resource.  On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.  #### PIN debit Returned for all PIN debit services. 

        :param id: The id of this PtsV2PayoutsPost201Response.
        :type: str
        """
        if id is not None and len(id) > 26:
            raise ValueError("Invalid value for `id`, length must be less than or equal to `26`")

        self._id = id

    @property
    def submit_time_utc(self):
        """
        Gets the submit_time_utc of this PtsV2PayoutsPost201Response.
        Time of request in UTC. `Format: YYYY-MM-DDThh:mm:ssZ`  Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. 

        :return: The submit_time_utc of this PtsV2PayoutsPost201Response.
        :rtype: str
        """
        return self._submit_time_utc

    @submit_time_utc.setter
    def submit_time_utc(self, submit_time_utc):
        """
        Sets the submit_time_utc of this PtsV2PayoutsPost201Response.
        Time of request in UTC. `Format: YYYY-MM-DDThh:mm:ssZ`  Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. 

        :param submit_time_utc: The submit_time_utc of this PtsV2PayoutsPost201Response.
        :type: str
        """

        self._submit_time_utc = submit_time_utc

    @property
    def status(self):
        """
        Gets the status of this PtsV2PayoutsPost201Response.
        The status of the submitted transaction.  Possible values:  - ACCEPTED  - DECLINED  - INVALID_REQUEST 

        :return: The status of this PtsV2PayoutsPost201Response.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this PtsV2PayoutsPost201Response.
        The status of the submitted transaction.  Possible values:  - ACCEPTED  - DECLINED  - INVALID_REQUEST 

        :param status: The status of this PtsV2PayoutsPost201Response.
        :type: str
        """

        self._status = status

    @property
    def reconciliation_id(self):
        """
        Gets the reconciliation_id of this PtsV2PayoutsPost201Response.
        Cybersource or merchant generated transaction reference number. This is sent to the processor and is echoed back in the response to the merchant. This is This value is used for reconciliation purposes. 

        :return: The reconciliation_id of this PtsV2PayoutsPost201Response.
        :rtype: str
        """
        return self._reconciliation_id

    @reconciliation_id.setter
    def reconciliation_id(self, reconciliation_id):
        """
        Sets the reconciliation_id of this PtsV2PayoutsPost201Response.
        Cybersource or merchant generated transaction reference number. This is sent to the processor and is echoed back in the response to the merchant. This is This value is used for reconciliation purposes. 

        :param reconciliation_id: The reconciliation_id of this PtsV2PayoutsPost201Response.
        :type: str
        """
        if reconciliation_id is not None and len(reconciliation_id) > 25:
            raise ValueError("Invalid value for `reconciliation_id`, length must be less than or equal to `25`")

        self._reconciliation_id = reconciliation_id

    @property
    def error_information(self):
        """
        Gets the error_information of this PtsV2PayoutsPost201Response.

        :return: The error_information of this PtsV2PayoutsPost201Response.
        :rtype: PtsV2PayoutsPost201ResponseErrorInformation
        """
        return self._error_information

    @error_information.setter
    def error_information(self, error_information):
        """
        Sets the error_information of this PtsV2PayoutsPost201Response.

        :param error_information: The error_information of this PtsV2PayoutsPost201Response.
        :type: PtsV2PayoutsPost201ResponseErrorInformation
        """

        self._error_information = error_information

    @property
    def client_reference_information(self):
        """
        Gets the client_reference_information of this PtsV2PayoutsPost201Response.

        :return: The client_reference_information of this PtsV2PayoutsPost201Response.
        :rtype: PtsV2PaymentsPost201ResponseClientReferenceInformation
        """
        return self._client_reference_information

    @client_reference_information.setter
    def client_reference_information(self, client_reference_information):
        """
        Sets the client_reference_information of this PtsV2PayoutsPost201Response.

        :param client_reference_information: The client_reference_information of this PtsV2PayoutsPost201Response.
        :type: PtsV2PaymentsPost201ResponseClientReferenceInformation
        """

        self._client_reference_information = client_reference_information

    @property
    def merchant_information(self):
        """
        Gets the merchant_information of this PtsV2PayoutsPost201Response.

        :return: The merchant_information of this PtsV2PayoutsPost201Response.
        :rtype: PtsV2PayoutsPost201ResponseMerchantInformation
        """
        return self._merchant_information

    @merchant_information.setter
    def merchant_information(self, merchant_information):
        """
        Sets the merchant_information of this PtsV2PayoutsPost201Response.

        :param merchant_information: The merchant_information of this PtsV2PayoutsPost201Response.
        :type: PtsV2PayoutsPost201ResponseMerchantInformation
        """

        self._merchant_information = merchant_information

    @property
    def order_information(self):
        """
        Gets the order_information of this PtsV2PayoutsPost201Response.

        :return: The order_information of this PtsV2PayoutsPost201Response.
        :rtype: PtsV2PayoutsPost201ResponseOrderInformation
        """
        return self._order_information

    @order_information.setter
    def order_information(self, order_information):
        """
        Sets the order_information of this PtsV2PayoutsPost201Response.

        :param order_information: The order_information of this PtsV2PayoutsPost201Response.
        :type: PtsV2PayoutsPost201ResponseOrderInformation
        """

        self._order_information = order_information

    @property
    def processor_information(self):
        """
        Gets the processor_information of this PtsV2PayoutsPost201Response.

        :return: The processor_information of this PtsV2PayoutsPost201Response.
        :rtype: PtsV2PayoutsPost201ResponseProcessorInformation
        """
        return self._processor_information

    @processor_information.setter
    def processor_information(self, processor_information):
        """
        Sets the processor_information of this PtsV2PayoutsPost201Response.

        :param processor_information: The processor_information of this PtsV2PayoutsPost201Response.
        :type: PtsV2PayoutsPost201ResponseProcessorInformation
        """

        self._processor_information = processor_information

    @property
    def recipient_information(self):
        """
        Gets the recipient_information of this PtsV2PayoutsPost201Response.

        :return: The recipient_information of this PtsV2PayoutsPost201Response.
        :rtype: PtsV2PayoutsPost201ResponseRecipientInformation
        """
        return self._recipient_information

    @recipient_information.setter
    def recipient_information(self, recipient_information):
        """
        Sets the recipient_information of this PtsV2PayoutsPost201Response.

        :param recipient_information: The recipient_information of this PtsV2PayoutsPost201Response.
        :type: PtsV2PayoutsPost201ResponseRecipientInformation
        """

        self._recipient_information = recipient_information

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PayoutsPost201Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TssV2TransactionsGet200ResponseOrderInformationLineItems(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'product_code': 'str',
        'product_name': 'str',
        'product_sku': 'str',
        'tax_amount': 'str',
        'quantity': 'int',
        'unit_price': 'str',
        'fulfillment_type': 'str'
    }

    attribute_map = {
        'product_code': 'productCode',
        'product_name': 'productName',
        'product_sku': 'productSku',
        'tax_amount': 'taxAmount',
        'quantity': 'quantity',
        'unit_price': 'unitPrice',
        'fulfillment_type': 'fulfillmentType'
    }

    def __init__(self, product_code=None, product_name=None, product_sku=None, tax_amount=None, quantity=None, unit_price=None, fulfillment_type=None):
        """
        TssV2TransactionsGet200ResponseOrderInformationLineItems - a model defined in Swagger
        """

        self._product_code = None
        self._product_name = None
        self._product_sku = None
        self._tax_amount = None
        self._quantity = None
        self._unit_price = None
        self._fulfillment_type = None

        if product_code is not None:
          self.product_code = product_code
        if product_name is not None:
          self.product_name = product_name
        if product_sku is not None:
          self.product_sku = product_sku
        if tax_amount is not None:
          self.tax_amount = tax_amount
        if quantity is not None:
          self.quantity = quantity
        if unit_price is not None:
          self.unit_price = unit_price
        if fulfillment_type is not None:
          self.fulfillment_type = fulfillment_type

    @property
    def product_code(self):
        """
        Gets the product_code of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        Type of product. This value is used to determine the category that the product is in: electronic, handling, physical, service, or shipping. The default value is **default**.  For a payment, when you set this field to a value other than default or any of the values related to shipping and handling, below fields _quantity_, _productName_, and _productSKU_ are required. 

        :return: The product_code of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        :rtype: str
        """
        return self._product_code

    @product_code.setter
    def product_code(self, product_code):
        """
        Sets the product_code of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        Type of product. This value is used to determine the category that the product is in: electronic, handling, physical, service, or shipping. The default value is **default**.  For a payment, when you set this field to a value other than default or any of the values related to shipping and handling, below fields _quantity_, _productName_, and _productSKU_ are required. 

        :param product_code: The product_code of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        :type: str
        """
        if product_code is not None and len(product_code) > 255:
            raise ValueError("Invalid value for `product_code`, length must be less than or equal to `255`")

        self._product_code = product_code

    @property
    def product_name(self):
        """
        Gets the product_name of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        For PAYMENT and CAPTURE API, this field is required when above _productCode_ is not **default** or one of the values related to shipping and handling. 

        :return: The product_name of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        :rtype: str
        """
        return self._product_name

    @product_name.setter
    def product_name(self, product_name):
        """
        Sets the product_name of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        For PAYMENT and CAPTURE API, this field is required when above _productCode_ is not **default** or one of the values related to shipping and handling. 

        :param product_name: The product_name of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        :type: str
        """
        if product_name is not None and len(product_name) > 255:
            raise ValueError("Invalid value for `product_name`, length must be less than or equal to `255`")

        self._product_name = product_name

    @property
    def product_sku(self):
        """
        Gets the product_sku of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        Identification code for the product. For Payment and Capture APIs, this field is required when above `productCode` is not **default** or one of the values related to shipping and/or handling. 

        :return: The product_sku of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        :rtype: str
        """
        return self._product_sku

    @product_sku.setter
    def product_sku(self, product_sku):
        """
        Sets the product_sku of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        Identification code for the product. For Payment and Capture APIs, this field is required when above `productCode` is not **default** or one of the values related to shipping and/or handling. 

        :param product_sku: The product_sku of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        :type: str
        """
        if product_sku is not None and len(product_sku) > 255:
            raise ValueError("Invalid value for `product_sku`, length must be less than or equal to `255`")

        self._product_sku = product_sku

    @property
    def tax_amount(self):
        """
        Gets the tax_amount of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        Total tax to apply to the product. This value cannot be negative. The tax amount and the offer amount must be in the same currency. The tax amount field is additive.  The following example uses a two-exponent currency such as USD:  1. You include each line item in your request.     - 1st line item has `amount=10.00`, `quantity=1`, and `taxAmount=0.80`     - 2nd line item has `amount=20.00`, `quantity=1`, and `taxAmount=1.60` 2. The total amount authorized will be 32.40, not 30.00 with 2.40 of tax included.  This field is frequently used for Level II and Level III transactions.  For details, see `tax_amount` field description in [Level II and Level III Processing Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/Level_2_3_SCMP_API/html/) 

        :return: The tax_amount of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        :rtype: str
        """
        return self._tax_amount

    @tax_amount.setter
    def tax_amount(self, tax_amount):
        """
        Sets the tax_amount of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        Total tax to apply to the product. This value cannot be negative. The tax amount and the offer amount must be in the same currency. The tax amount field is additive.  The following example uses a two-exponent currency such as USD:  1. You include each line item in your request.     - 1st line item has `amount=10.00`, `quantity=1`, and `taxAmount=0.80`     - 2nd line item has `amount=20.00`, `quantity=1`, and `taxAmount=1.60` 2. The total amount authorized will be 32.40, not 30.00 with 2.40 of tax included.  This field is frequently used for Level II and Level III transactions.  For details, see `tax_amount` field description in [Level II and Level III Processing Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/Level_2_3_SCMP_API/html/) 

        :param tax_amount: The tax_amount of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        :type: str
        """
        if tax_amount is not None and len(tax_amount) > 15:
            raise ValueError("Invalid value for `tax_amount`, length must be less than or equal to `15`")

        self._tax_amount = tax_amount

    @property
    def quantity(self):
        """
        Gets the quantity of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        For a payment or capture, this field is required when _productCode_ is not **default** or one of the values related to shipping and handling. 

        :return: The quantity of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """
        Sets the quantity of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        For a payment or capture, this field is required when _productCode_ is not **default** or one of the values related to shipping and handling. 

        :param quantity: The quantity of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        :type: int
        """
        if quantity is not None and quantity > 999999999:
            raise ValueError("Invalid value for `quantity`, must be a value less than or equal to `999999999`")
        if quantity is not None and quantity < 1:
            raise ValueError("Invalid value for `quantity`, must be a value greater than or equal to `1`")

        self._quantity = quantity

    @property
    def unit_price(self):
        """
        Gets the unit_price of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        Per-item price of the product. This value cannot be negative. You can include a decimal point (.), but you cannot include any other special characters. CyberSource truncates the amount to the correct number of decimal places.  For processor-specific information, see the amount field in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html) 

        :return: The unit_price of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        :rtype: str
        """
        return self._unit_price

    @unit_price.setter
    def unit_price(self, unit_price):
        """
        Sets the unit_price of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        Per-item price of the product. This value cannot be negative. You can include a decimal point (.), but you cannot include any other special characters. CyberSource truncates the amount to the correct number of decimal places.  For processor-specific information, see the amount field in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html) 

        :param unit_price: The unit_price of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        :type: str
        """
        if unit_price is not None and len(unit_price) > 15:
            raise ValueError("Invalid value for `unit_price`, length must be less than or equal to `15`")

        self._unit_price = unit_price

    @property
    def fulfillment_type(self):
        """
        Gets the fulfillment_type of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        The description for this field is not available.

        :return: The fulfillment_type of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        :rtype: str
        """
        return self._fulfillment_type

    @fulfillment_type.setter
    def fulfillment_type(self, fulfillment_type):
        """
        Sets the fulfillment_type of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        The description for this field is not available.

        :param fulfillment_type: The fulfillment_type of this TssV2TransactionsGet200ResponseOrderInformationLineItems.
        :type: str
        """

        self._fulfillment_type = fulfillment_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TssV2TransactionsGet200ResponseOrderInformationLineItems):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsPost201ResponseRiskInformationTravel(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'actual_final_destination': 'PtsV2PaymentsPost201ResponseRiskInformationTravelActualFinalDestination',
        'first_departure': 'PtsV2PaymentsPost201ResponseRiskInformationTravelFirstDeparture',
        'first_destination': 'PtsV2PaymentsPost201ResponseRiskInformationTravelFirstDestination',
        'last_destination': 'PtsV2PaymentsPost201ResponseRiskInformationTravelLastDestination'
    }

    attribute_map = {
        'actual_final_destination': 'actualFinalDestination',
        'first_departure': 'firstDeparture',
        'first_destination': 'firstDestination',
        'last_destination': 'lastDestination'
    }

    def __init__(self, actual_final_destination=None, first_departure=None, first_destination=None, last_destination=None):
        """
        PtsV2PaymentsPost201ResponseRiskInformationTravel - a model defined in Swagger
        """

        self._actual_final_destination = None
        self._first_departure = None
        self._first_destination = None
        self._last_destination = None

        if actual_final_destination is not None:
          self.actual_final_destination = actual_final_destination
        if first_departure is not None:
          self.first_departure = first_departure
        if first_destination is not None:
          self.first_destination = first_destination
        if last_destination is not None:
          self.last_destination = last_destination

    @property
    def actual_final_destination(self):
        """
        Gets the actual_final_destination of this PtsV2PaymentsPost201ResponseRiskInformationTravel.

        :return: The actual_final_destination of this PtsV2PaymentsPost201ResponseRiskInformationTravel.
        :rtype: PtsV2PaymentsPost201ResponseRiskInformationTravelActualFinalDestination
        """
        return self._actual_final_destination

    @actual_final_destination.setter
    def actual_final_destination(self, actual_final_destination):
        """
        Sets the actual_final_destination of this PtsV2PaymentsPost201ResponseRiskInformationTravel.

        :param actual_final_destination: The actual_final_destination of this PtsV2PaymentsPost201ResponseRiskInformationTravel.
        :type: PtsV2PaymentsPost201ResponseRiskInformationTravelActualFinalDestination
        """

        self._actual_final_destination = actual_final_destination

    @property
    def first_departure(self):
        """
        Gets the first_departure of this PtsV2PaymentsPost201ResponseRiskInformationTravel.

        :return: The first_departure of this PtsV2PaymentsPost201ResponseRiskInformationTravel.
        :rtype: PtsV2PaymentsPost201ResponseRiskInformationTravelFirstDeparture
        """
        return self._first_departure

    @first_departure.setter
    def first_departure(self, first_departure):
        """
        Sets the first_departure of this PtsV2PaymentsPost201ResponseRiskInformationTravel.

        :param first_departure: The first_departure of this PtsV2PaymentsPost201ResponseRiskInformationTravel.
        :type: PtsV2PaymentsPost201ResponseRiskInformationTravelFirstDeparture
        """

        self._first_departure = first_departure

    @property
    def first_destination(self):
        """
        Gets the first_destination of this PtsV2PaymentsPost201ResponseRiskInformationTravel.

        :return: The first_destination of this PtsV2PaymentsPost201ResponseRiskInformationTravel.
        :rtype: PtsV2PaymentsPost201ResponseRiskInformationTravelFirstDestination
        """
        return self._first_destination

    @first_destination.setter
    def first_destination(self, first_destination):
        """
        Sets the first_destination of this PtsV2PaymentsPost201ResponseRiskInformationTravel.

        :param first_destination: The first_destination of this PtsV2PaymentsPost201ResponseRiskInformationTravel.
        :type: PtsV2PaymentsPost201ResponseRiskInformationTravelFirstDestination
        """

        self._first_destination = first_destination

    @property
    def last_destination(self):
        """
        Gets the last_destination of this PtsV2PaymentsPost201ResponseRiskInformationTravel.

        :return: The last_destination of this PtsV2PaymentsPost201ResponseRiskInformationTravel.
        :rtype: PtsV2PaymentsPost201ResponseRiskInformationTravelLastDestination
        """
        return self._last_destination

    @last_destination.setter
    def last_destination(self, last_destination):
        """
        Sets the last_destination of this PtsV2PaymentsPost201ResponseRiskInformationTravel.

        :param last_destination: The last_destination of this PtsV2PaymentsPost201ResponseRiskInformationTravel.
        :type: PtsV2PaymentsPost201ResponseRiskInformationTravelLastDestination
        """

        self._last_destination = last_destination

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsPost201ResponseRiskInformationTravel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class TransactionBatchesApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """
	
    def __init__(self, merchant_config, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client
        self.api_client.set_configuration(merchant_config) 


    def get_transaction_batch_details(self, id, **kwargs):
        """
        Get Transaction Details for a given Batch Id
        Provides real-time detailed status information about the transactions that you previously uploaded in the Business Center or processed with the Offline Transaction File Submission service. 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_transaction_batch_details(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The batch id assigned for the template. (required)
        :param date upload_date: Date in which the original batch file was uploaded. Date must be in ISO-8601 format. Please refer the following link to know more about ISO 8601 format.[Rfc Date Format](https://xml2rfc.tools.ietf.org/public/rfc/html/rfc3339.html#anchor14) **Example date format:**  - yyyy-MM-dd 
        :param str status: Allows you to filter by rejected response.  Valid values: - Rejected 
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_transaction_batch_details_with_http_info(id, **kwargs)
        else:
            (data) = self.get_transaction_batch_details_with_http_info(id, **kwargs)
            return data

    def get_transaction_batch_details_with_http_info(self, id, **kwargs):
        """
        Get Transaction Details for a given Batch Id
        Provides real-time detailed status information about the transactions that you previously uploaded in the Business Center or processed with the Offline Transaction File Submission service. 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_transaction_batch_details_with_http_info(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The batch id assigned for the template. (required)
        :param date upload_date: Date in which the original batch file was uploaded. Date must be in ISO-8601 format. Please refer the following link to know more about ISO 8601 format.[Rfc Date Format](https://xml2rfc.tools.ietf.org/public/rfc/html/rfc3339.html#anchor14) **Example date format:**  - yyyy-MM-dd 
        :param str status: Allows you to filter by rejected response.  Valid values: - Rejected 
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'upload_date', 'status']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_transaction_batch_details" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_transaction_batch_details`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []
        if 'upload_date' in params:
            query_params.append(('uploadDate', params['upload_date']))
        if 'status' in params:
            query_params.append(('status', params['status']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['text/csv', 'application/xml', 'text/vnd.cybersource.map-csv'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(f'/pts/v1/transaction-batch-details/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_transaction_batch_id(self, id, **kwargs):
        """
        Get Individual Batch File
        Provide the search range
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_transaction_batch_id(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The batch id assigned for the template. (required)
        :return: PtsV1TransactionBatchesIdGet200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_transaction_batch_id_with_http_info(id, **kwargs)
        else:
            (data) = self.get_transaction_batch_id_with_http_info(id, **kwargs)
            return data

    def get_transaction_batch_id_with_http_info(self, id, **kwargs):
        """
        Get Individual Batch File
        Provide the search range
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_transaction_batch_id_with_http_info(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The batch id assigned for the template. (required)
        :return: PtsV1TransactionBatchesIdGet200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_transaction_batch_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_transaction_batch_id`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/hal+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(f'/pts/v1/transaction-batches/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='PtsV1TransactionBatchesIdGet200Response',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_transaction_batches(self, start_time, end_time, **kwargs):
        """
        Get a List of Batch Files
        Provide the search range
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_transaction_batches(start_time, end_time, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param datetime start_time: Valid report Start Time in **ISO 8601 format** Please refer the following link to know more about ISO 8601 format.[Rfc Date Format](https://xml2rfc.tools.ietf.org/public/rfc/html/rfc3339.html#anchor14)   **Example date format:**   - yyyy-MM-dd'T'HH:mm:ss.SSSZZ  (required)
        :param datetime end_time: Valid report End Time in **ISO 8601 format** Please refer the following link to know more about ISO 8601 format.[Rfc Date Format](https://xml2rfc.tools.ietf.org/public/rfc/html/rfc3339.html#anchor14)   **Example date format:**   - yyyy-MM-dd'T'HH:mm:ss.SSSZZ  (required)
        :return: PtsV1TransactionBatchesGet200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_transaction_batches_with_http_info(start_time, end_time, **kwargs)
        else:
            (data) = self.get_transaction_batches_with_http_info(start_time, end_time, **kwargs)
            return data

    def get_transaction_batches_with_http_info(self, start_time, end_time, **kwargs):
        """
        Get a List of Batch Files
        Provide the search range
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_transaction_batches_with_http_info(start_time, end_time, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param datetime start_time: Valid report Start Time in **ISO 8601 format** Please refer the following link to know more about ISO 8601 format.[Rfc Date Format](https://xml2rfc.tools.ietf.org/public/rfc/html/rfc3339.html#anchor14)   **Example date format:**   - yyyy-MM-dd'T'HH:mm:ss.SSSZZ  (required)
        :param datetime end_time: Valid report End Time in **ISO 8601 format** Please refer the following link to know more about ISO 8601 format.[Rfc Date Format](https://xml2rfc.tools.ietf.org/public/rfc/html/rfc3339.html#anchor14)   **Example date format:**   - yyyy-MM-dd'T'HH:mm:ss.SSSZZ  (required)
        :return: PtsV1TransactionBatchesGet200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_time', 'end_time']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_transaction_batches" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'start_time' is set
        if ('start_time' not in params) or (params['start_time'] is None):
            raise ValueError("Missing the required parameter `start_time` when calling `get_transaction_batches`")
        # verify the required parameter 'end_time' is set
        if ('end_time' not in params) or (params['end_time'] is None):
            raise ValueError("Missing the required parameter `end_time` when calling `get_transaction_batches`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in params:
            query_params.append(('startTime', params['start_time']))
        if 'end_time' in params:
            query_params.append(('endTime', params['end_time']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/hal+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(f'/pts/v1/transaction-batches', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='PtsV1TransactionBatchesGet200Response',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Riskv1exportcomplianceinquiriesExportComplianceInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address_operator': 'str',
        'weights': 'Riskv1exportcomplianceinquiriesExportComplianceInformationWeights',
        'sanction_lists': 'list[str]'
    }

    attribute_map = {
        'address_operator': 'addressOperator',
        'weights': 'weights',
        'sanction_lists': 'sanctionLists'
    }

    def __init__(self, address_operator=None, weights=None, sanction_lists=None):
        """
        Riskv1exportcomplianceinquiriesExportComplianceInformation - a model defined in Swagger
        """

        self._address_operator = None
        self._weights = None
        self._sanction_lists = None

        if address_operator is not None:
          self.address_operator = address_operator
        if weights is not None:
          self.weights = weights
        if sanction_lists is not None:
          self.sanction_lists = sanction_lists

    @property
    def address_operator(self):
        """
        Gets the address_operator of this Riskv1exportcomplianceinquiriesExportComplianceInformation.
        Parts of the customer’s information that must match with an entry in the DPL (denied parties list) before a match occurs. This field can contain one of the following values: - AND: (default) The customer’s name or company and the customer’s address must appear in the database. - OR: The customer’s name must appear in the database. - IGNORE: You want the service to detect a match only of the customer’s name or company but not of the address. 

        :return: The address_operator of this Riskv1exportcomplianceinquiriesExportComplianceInformation.
        :rtype: str
        """
        return self._address_operator

    @address_operator.setter
    def address_operator(self, address_operator):
        """
        Sets the address_operator of this Riskv1exportcomplianceinquiriesExportComplianceInformation.
        Parts of the customer’s information that must match with an entry in the DPL (denied parties list) before a match occurs. This field can contain one of the following values: - AND: (default) The customer’s name or company and the customer’s address must appear in the database. - OR: The customer’s name must appear in the database. - IGNORE: You want the service to detect a match only of the customer’s name or company but not of the address. 

        :param address_operator: The address_operator of this Riskv1exportcomplianceinquiriesExportComplianceInformation.
        :type: str
        """

        self._address_operator = address_operator

    @property
    def weights(self):
        """
        Gets the weights of this Riskv1exportcomplianceinquiriesExportComplianceInformation.

        :return: The weights of this Riskv1exportcomplianceinquiriesExportComplianceInformation.
        :rtype: Riskv1exportcomplianceinquiriesExportComplianceInformationWeights
        """
        return self._weights

    @weights.setter
    def weights(self, weights):
        """
        Sets the weights of this Riskv1exportcomplianceinquiriesExportComplianceInformation.

        :param weights: The weights of this Riskv1exportcomplianceinquiriesExportComplianceInformation.
        :type: Riskv1exportcomplianceinquiriesExportComplianceInformationWeights
        """

        self._weights = weights

    @property
    def sanction_lists(self):
        """
        Gets the sanction_lists of this Riskv1exportcomplianceinquiriesExportComplianceInformation.
        Use this field to specify which list(s) you want checked with the request. The reply will include the list name as well as the response data. To check against multiple lists, enter multiple list codes separated by a caret (^). For more information, see \"Restricted and Denied Parties List,\" page 68. 

        :return: The sanction_lists of this Riskv1exportcomplianceinquiriesExportComplianceInformation.
        :rtype: list[str]
        """
        return self._sanction_lists

    @sanction_lists.setter
    def sanction_lists(self, sanction_lists):
        """
        Sets the sanction_lists of this Riskv1exportcomplianceinquiriesExportComplianceInformation.
        Use this field to specify which list(s) you want checked with the request. The reply will include the list name as well as the response data. To check against multiple lists, enter multiple list codes separated by a caret (^). For more information, see \"Restricted and Denied Parties List,\" page 68. 

        :param sanction_lists: The sanction_lists of this Riskv1exportcomplianceinquiriesExportComplianceInformation.
        :type: list[str]
        """

        self._sanction_lists = sanction_lists

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Riskv1exportcomplianceinquiriesExportComplianceInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
